@@ -85,7 +85,7 @@ impl Client {
         authentication: Authentication,
     ) -> Self {
         let good_host = host.into().trim_end_matches("/").to_string();
-        let me = UserId::parse_with_server_name(
+        let mut me = UserId::parse_with_server_name(
             username.into(),
             &ruma::ServerName::parse(server_name.into()).unwrap(),
         )
@@ -109,6 +109,11 @@ impl Client {
                 .await
                 .unwrap(),
         };
+        me = client
+            .send_request(ruma::api::client::account::whoami::v3::Request::new())
+            .await
+            .unwrap()
+            .user_id;
         Self {
             client: client,
             host: good_host, //host.into().trim_end_matches("/").to_string(),
